==> com.deepin.lianliankan_6.0.5.tar.xz: BUILD/translations/deepin-lianliankan_km_KH.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="km_KH">
<context>
    <name>CloseWindowDialog</name>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="34"/>
        <source>Are you sure you want to exit the game?</source>
        <translation>តើអ្នកប្រាកដថាត្រូវបោះបដិវត្តពី​ហ្គេម?</translation>
    </message>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="42"/>
        <source>Keep Playing</source>
        <translation>បន្តលេង</translation>
    </message>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="43"/>
        <source>Exit</source>
        <translation>បោះបដិវត្ត</translation>
    </message>
</context>
<context>
    <name>GameoverBlurEffectWidget</name>
    <message>
        <location filename="../src/source/gameoverblureffectwidget.cpp" line="93"/>
        <source>Play Again</source>
        <translation>លេងម្ដងទៀត</translation>
    </message>
    <message>
        <location filename="../src/source/gameoverblureffectwidget.cpp" line="94"/>
        <source>Have a Rest</source>
        <translation>ក្លាយក្រោយ​មុខ</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="52"/>
        <source>LianLianKan</source>
        <translation>លេងលេងកាន</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="53"/>
        <source>Lianliankan is a puzzle game.</source>
        <translation>លេងលេងកានគឺជាហ្គេមផ្នែកដោយ​ស្វ័យប្រវត្តិ</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../src/source/mainpage.cpp" line="32"/>
        <source>Easy</source>
        <translation>ងាយ</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="33"/>
        <source>Normal</source>
        <translation>ស្តីស្តាយ</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="34"/>
        <source>Hard</source>
        <translation>ល្អ</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="52"/>
        <source>Select Level</source>
        <translation>ជ្រើសរើសកម្រិត</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="97"/>
        <source>FAIL</source>
        <translation>បាត់បង់</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="100"/>
        <source>VICTORY</source>
        <translation>បាន​សំណាក់</translation>
    </message>
</context>
</TS>

==> com.deepin.lianliankan_6.0.11.tar.xz: BUILD/translations/deepin-lianliankan_km_KH.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="km_KH">
<context>
    <name>CloseWindowDialog</name>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="34"/>
        <source>Are you sure you want to exit the game?</source>
        <translation>តើអ្នកប្រាកដថាត្រូវបោះបដិវត្តពី​ហ្គេម?</translation>
    </message>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="42"/>
        <source>Keep Playing</source>
        <translation>បន្តលេង</translation>
    </message>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="43"/>
        <source>Exit</source>
        <translation>បោះបដិវត្ត</translation>
    </message>
</context>
<context>
    <name>GameoverBlurEffectWidget</name>
    <message>
        <location filename="../src/source/gameoverblureffectwidget.cpp" line="93"/>
        <source>Play Again</source>
        <translation>លេងម្ដងទៀត</translation>
    </message>
    <message>
        <location filename="../src/source/gameoverblureffectwidget.cpp" line="94"/>
        <source>Have a Rest</source>
        <translation>ក្លាយក្រោយ​មុខ</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="52"/>
        <location filename="../src/main.cpp" line="54"/>
        <location filename="../src/main.cpp" line="55"/>
        <source>LianLianKan</source>
        <translation>លេងលេងកាន</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="53"/>
        <source>Lianliankan is a puzzle game.</source>
        <translation>លេងលេងកានគឺជាហ្គេមផ្នែកដោយ​ស្វ័យប្រវត្តិ</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../src/source/mainpage.cpp" line="32"/>
        <source>Easy</source>
        <translation>ងាយ</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="33"/>
        <source>Normal</source>
        <translation>ស្តីស្តាយ</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="34"/>
        <source>Hard</source>
        <translation>ល្អ</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="52"/>
        <source> Select Level </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="97"/>
        <source>FAIL</source>
        <translation>បាត់បង់</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="100"/>
        <source>VICTORY</source>
        <translation>បាន​សំណាក់</translation>
    </message>
</context>
</TS>
